plot_continuous_legend.RdPlot a continuous color legend for the diverging color scheme.
plot_continuous_legend(
min = -3,
max = 3,
neutral_min = -0.5,
neutral_max = 0.5,
low = "#7f0000",
mid = "#ffffff",
high = "#006400",
n = 801,
unit = 1,
title = "Z"
)Minimum value that maps to the darkest red (values below are clipped).
Maximum value that maps to the darkest green (values above are clipped).
Minimum value of the white "dead zone" (values above are colored white).
Maximum value of the white "dead zone" (values below are colored white).
Color for low end (default dark red).
Color for midpoint (default white).
Color for high end (default dark green).
Number of discrete colors used internally for the gradient.
Title for the legend.
A plot of the color legend.